Sockeye Documentation
=====================

This is the documentation for sockeye,
a framework for sequence-to-sequence modeling with `MXNet <http://www.mxnet.io/>`_.
To get started, please read through the :doc:`README </README>`.

The individual modules and functions of the project are documented under :doc:`Python Modules </modules>`.

For Contributors
----------------
If you want to contribute or develop for sockeye, please see the :doc:`Developer Guide </development>`.


Table of Contents
-----------------

.. toctree::
    :maxdepth: 4

    README
    user_documentation
    development
    CHANGELOG
    faq
    modules

Resources
---------

* :ref:`genindex`
* :ref:`modindex`
